==> qt-creator-opensource-src-4.8.0.zip: qt-creator-opensource-src-4.8.0/src/plugins/clangrefactoring/refactoringprojectupdater.cpp <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "refactoringprojectupdater.h"

#include <cpptools/cppmodelmanager.h>

namespace ClangRefactoring {

void RefactoringProjectUpdater::precompiledHeaderUpdated(const QString &projectPartId,
                                                         const QString &,
                                                         long long)
{
    auto projectPart = m_cppModelManager.projectPartForId(projectPartId);
    if (projectPart)
        updateProjectParts({projectPart.data()});
}

void RefactoringProjectUpdater::precompiledHeaderRemoved(const QString &projectPartId)
{
    removeProjectParts({projectPartId});
}

} // namespace ClangRefactoring

==> qt-creator-opensource-src-4.9.2.zip: qt-creator-opensource-src-4.9.2/src/plugins/clangrefactoring/refactoringprojectupdater.cpp <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "refactoringprojectupdater.h"

#include <cpptools/cppmodelmanager.h>
#include <projectpartsstorageinterface.h>

namespace ClangRefactoring {

void RefactoringProjectUpdater::precompiledHeaderUpdated(ClangBackEnd::ProjectPartId projectPartId,
                                                         const QString &,
                                                         long long)
{
    const QString projectPartName = fetchProjectPartName(projectPartId);

    auto projectPart = m_cppModelManager.projectPartForId(projectPartName);
    if (projectPart)
        updateProjectParts({projectPart.data()}, {});
}

void RefactoringProjectUpdater::precompiledHeaderRemoved(ClangBackEnd::ProjectPartId projectPartId)
{
    removeProjectParts({projectPartId});
}

} // namespace ClangRefactoring
